Index: src/code.l
===================================================================
--- src/code.l	(Revision 728)
+++ src/code.l	(Arbeitskopie)
@@ -1890,7 +1890,7 @@
 					  {
 					    if (ambig) // multiple input files match the name
 					    {
-					      //printf("===== yes %s is ambigious\n",yytext);
+					      //printf("===== yes %s is ambiguous\n",yytext);
 					      QCString name = convertToQCString(QDir::cleanDirPath(yytext));
 					      if (!name.isEmpty() && g_sourceFileDef)
 					      {
Index: src/cmdmapper.cpp
===================================================================
--- src/cmdmapper.cpp	(Revision 728)
+++ src/cmdmapper.cpp	(Arbeitskopie)
@@ -159,7 +159,7 @@
   { "div",        HTML_DIV },
 
   { "c",            XML_C },
-  // { "code",       XML_CODE },  <= ambigious <code> is also a HTML tag
+  // { "code",       XML_CODE },  <= ambiguous <code> is also a HTML tag
   { "description",  XML_DESCRIPTION },
   { "example",      XML_EXAMPLE },
   { "exception",    XML_EXCEPTION },
Index: src/instdox.cpp
===================================================================
--- src/instdox.cpp	(Revision 728)
+++ src/instdox.cpp	(Arbeitskopie)
@@ -110,7 +110,7 @@
     t << "  }\n";
     t << "  elsif ( ! $quiet && $sub ne \"_doc\" && $sub ne \"_cgi\" )\n";
     t << "  {\n";
-    t << "    print \"Substituting $subst{$sub} for each occurence of tag file $sub\\n\"; \n";
+    t << "    print \"Substituting $subst{$sub} for each occurrence of tag file $sub\\n\"; \n";
     t << "  }\n";
     t << "}\n";
     t << "\n";
Index: src/memberlist.cpp
===================================================================
--- src/memberlist.cpp	(Revision 728)
+++ src/memberlist.cpp	(Arbeitskopie)
@@ -221,7 +221,7 @@
                 }
               }
             }
-            // if this is an anoymous enum and there are variables of this
+            // if this is an anonymous enum and there are variables of this
             // enum type (i.e. enumVars>0), then we do not show the enum here.
             if (enumVars==0) // show enum here
             {
@@ -307,7 +307,7 @@
                 }
               }
             }
-            // if this is an anoymous enum and there are variables of this
+            // if this is an anonymous enum and there are variables of this
             // enum type (i.e. enumVars>0), then we do not show the enum here.
             if (enumVars==0) // show enum here
             {
Index: src/lodepng.h
===================================================================
--- src/lodepng.h	(Revision 728)
+++ src/lodepng.h	(Arbeitskopie)
@@ -1120,7 +1120,7 @@
 *) 53: size of zlib data too small
 *) 55: jumped past tree while generating huffman tree, this could be when the
        tree will have more leaves than symbols after generating it out of the
-       given lenghts. They call this an oversubscribed dynamic bit lengths tree in zlib.
+       given lengths. They call this an oversubscribed dynamic bit lengths tree in zlib.
 *) 56: given output image colorType or bitDepth not supported for color conversion
 *) 57: invalid CRC encountered (checking CRC can be disabled)
 *) 58: invalid ADLER32 encountered (checking ADLER32 can be disabled)
Index: src/docparser.cpp
===================================================================
--- src/docparser.cpp	(Revision 728)
+++ src/docparser.cpp	(Arbeitskopie)
@@ -297,7 +297,7 @@
   else if (ambig)
   {
     QCString text;
-    text.sprintf("Warning: image file name %s is ambigious.\n",fileName);
+    text.sprintf("Warning: image file name %s is ambiguous.\n",fileName);
     text+="Possible candidates:\n";
     text+=showFileDefMatches(Doxygen::imageNameDict,fileName);
     warn_doc_error(g_fileName,doctokenizerYYlineno,text);
@@ -1550,7 +1550,7 @@
   }
   else if (ambig)
   {
-    warn_doc_error(g_fileName,doctokenizerYYlineno,"Warning: included file name %s is ambigious"
+    warn_doc_error(g_fileName,doctokenizerYYlineno,"Warning: included file name %s is ambiguous"
            "Possible candidates:\n%s",file.data(),
            showFileDefMatches(Doxygen::exampleNameDict,file).data()
           );
@@ -2480,7 +2480,7 @@
   }
   else if (ambig)
   {
-    warn_doc_error(g_fileName,doctokenizerYYlineno,"Warning: included dot file name %s is ambigious.\n"
+    warn_doc_error(g_fileName,doctokenizerYYlineno,"Warning: included dot file name %s is ambiguous.\n"
            "Possible candidates:\n%s",m_name.data(),
            showFileDefMatches(Doxygen::exampleNameDict,m_name).data()
           );
Index: src/classdef.cpp
===================================================================
--- src/classdef.cpp	(Revision 728)
+++ src/classdef.cpp	(Arbeitskopie)
@@ -2002,7 +2002,7 @@
 }
 
 /*! called from MemberDef::writeDeclaration() to (recusively) write the 
- *  definition of an annonymous struct, union or class.
+ *  definition of an anonymous struct, union or class.
  */
 void ClassDef::writeDeclaration(OutputList &ol,MemberDef *md,bool inGroup)
 {
@@ -2125,9 +2125,9 @@
 
   return // show all classes or a subclass is visible
       (allExternals || hasNonReferenceSuperClass()) &&
-      // and not an annonymous compound
+      // and not an anonymous compound
       name().find('@')==-1 &&
-      // not an artifically introduced class
+      // not an artificially introduced class
       !isArtificial() &&
       // and not privately inherited
       (m_impl->prot!=Private || extractPrivate) &&
Index: src/htmlgen.cpp
===================================================================
--- src/htmlgen.cpp	(Revision 728)
+++ src/htmlgen.cpp	(Arbeitskopie)
@@ -1666,7 +1666,7 @@
   }
 }
 
-// annonymous type:
+// anonymous type:
 //  0 = single column right aligned
 //  1 = double column left aligned
 //  2 = single column left aligned
Index: src/scanner.l
===================================================================
--- src/scanner.l	(Revision 728)
+++ src/scanner.l	(Arbeitskopie)
@@ -3172,8 +3172,8 @@
   					  if (msName.isEmpty() && !current->name.isEmpty())
 					  { 
 					    // see if the compound does not have a name or is inside another
-					    // annonymous compound. If so we insert a 
-					    // special `annonymous' variable.
+					    // anonymous compound. If so we insert a 
+					    // special `anonymous' variable.
 					    //Entry *p=current_root;
 					    Entry *p=current;
 					    while (p)
@@ -3186,8 +3186,8 @@
 						int pi = (i==-1) ? 0 : i+2;
 						if (p->name.at(pi)=='@')
 						{
-						  // annonymous compound inside -> insert dummy variable name
-						  //printf("Adding annonymous variable for scope %s\n",p->name.data());
+						  // anonymous compound inside -> insert dummy variable name
+						  //printf("Adding anonymous variable for scope %s\n",p->name.data());
 						  msName.sprintf("@%d",anonCount++); 
 						  break;
 						}
@@ -4569,7 +4569,7 @@
 					  else
 					    BEGIN( CopyArgComment );
 					}
-<CSConstraintType,CSConstraintName>"#"	{ // artifically inserted token to signal end of comment block
+<CSConstraintType,CSConstraintName>"#"	{ // artificially inserted token to signal end of comment block
                                           current->typeConstr->last()->docs = fullArgString;
   					}
 <CSConstraintType>"{"			{ // end of type constraint reached
Index: src/util.cpp
===================================================================
--- src/util.cpp	(Revision 728)
+++ src/util.cpp	(Arbeitskopie)
@@ -131,7 +131,7 @@
 const int maxInheritanceDepth = 100000; 
 
 /*! 
-  Removes all anoymous scopes from string s
+  Removes all anonymous scopes from string s
   Possible examples:
 \verbatim
    "bla::@10::blep"      => "bla::blep"
@@ -197,7 +197,7 @@
 }
 
 
 // strip annonymous left hand side part of the scope
 QCString stripAnonymousNamespaceScope(const QCString &s)
 {
   int i,p=0,l;
@@ -1251,7 +1251,7 @@
   //printf("  bestMatch=%p bestResolvedType=%s\n",bestMatch,bestResolvedType.data());
 }
 
-/* Find the fully qualified class name refered to by the input class
+/* Find the fully qualified class name referred to by the input class
  * or typedef name against the input scope.
  * Loops through scope and each of its parent scopes looking for a
  * match against the input name. Can recursively call itself when 
@@ -1429,7 +1429,7 @@
   return bestMatch;
 }
 
-/* Find the fully qualified class name refered to by the input class
+/* Find the fully qualified class name referred to by the input class
  * or typedef name against the input scope.
  * Loops through scope and each of its parent scopes looking for a
  * match against the input name. 
@@ -1465,7 +1465,7 @@
   {
     if (!mayBeHidden || !result->isHidden())
     {
-      result=0; // don't link to artifical/hidden classes unless explicitly allowed
+      result=0; // don't link to artificial/hidden classes unless explicitly allowed
     }
   }
   //printf("getResolvedClass(%s,%s)=%s\n",scope?scope->name().data():"<global>",
@@ -1483,7 +1483,7 @@
   int b = s.findRev("operator",i);
   if (b==-1) return FALSE; // not found
   b+=8;
-  while (b<i) // check if there are only spaces inbetween 
+  while (b<i) // check if there are only spaces in between 
     // the operator and the >
   {
     if (!isspace((uchar)s.at(b))) return FALSE;
@@ -2000,7 +2000,7 @@
 
 //----------------------------------------------------------------------------
 
-/*! takes the \a buf of the given lenght \a len and converts CR LF (DOS)
+/*! takes the \a buf of the given length \a len and converts CR LF (DOS)
  * or CR (MAC) line ending to LF (Unix).  Returns the length of the
  * converted content (i.e. the same as \a len (Unix, MAC) or
  * smaller (DOS).
@@ -2683,9 +2683,9 @@
   srcAType.stripPrefix("class ");
   dstAType.stripPrefix("class ");
 
-  // allow distingishing "const A" from "const B" even though 
+  // allow distinguishing "const A" from "const B" even though 
   // from a syntactic point of view they would be two names of the same 
-  // type "const". This is not fool prove ofcourse, but should at least 
+  // type "const". This is not fool prove of course, but should at least 
   // catch the most common cases.
   if ((srcAType=="const" || srcAType=="volatile") && !srcAName.isEmpty())
   {
@@ -3470,7 +3470,7 @@
       dstA->defval=srcA->defval.copy();
     }
 
-    // fix wrongly detected const or volatile specificiers before merging.
+    // fix wrongly detected const or volatile specifiers before merging.
     // example: "const A *const" is detected as type="const A *" name="const"
     if (srcA->name=="const" || srcA->name=="volatile")
     {
@@ -4486,7 +4486,7 @@
 #endif
 
 //----------------------------------------------------------------------
-// substitute all occurences of `src' in `s' by `dst'
+// substitute all occurrences of `src' in `s' by `dst'
 
 QCString substitute(const char *s,const char *src,const char *dst)
 {
@@ -4577,7 +4577,7 @@
         return fd;
       }
     }
-    else // file name alone is ambigious
+    else // file name alone is ambiguous
     {
       int count=0;
       FileNameIterator fni(*fn);
@@ -5865,7 +5865,7 @@
 
 #if 0
 /*!
- * Function converts Latin1 character to latex string representin the same
+ * Function converts Latin1 character to latex string representing the same
  * character.
  */
 static void latin1ToLatex(QTextStream &t,unsigned char c)
@@ -5941,7 +5941,7 @@
 }
 
 /*!
- * Function converts Latin2 character to latex string representin the same
+ * Function converts Latin2 character to latex string representing the same
  * character.
  */
 static void latin2ToLatex(QTextStream &t,unsigned char c)
@@ -6136,7 +6136,7 @@
                              t << (char)c;
                            }
                          }
-                         else // ascii char => see if we can insert a hypenation hint
+                         else // ascii char => see if we can insert a hyphenation hint
                          {
                            if (isupper(c) && islower(pc) && !insideTabbing) t << "\\-";
                            t << (char)c;    
@@ -6148,7 +6148,7 @@
                          {
                            t << (char)c;
                          }
-                         else // ascii char => see if we can insert a hypenation hint
+                         else // ascii char => see if we can insert a hyphenation hint
                          {
                            if (isupper(c) && islower(pc) && !insideTabbing) t << "\\-";
                            t << (char)c;
@@ -6401,7 +6401,7 @@
 
 bool updateLanguageMapping(const QCString &extension,const QCString &language)
 {
-  //getLanguageFromFileName("dummy"); // force initializion of the g_extLookup map
+  //getLanguageFromFileName("dummy"); // force initialization of the g_extLookup map
   const Lang2ExtMap *p = g_lang2extMap;
   QCString langName = language.lower();
   while (p->langName)
@@ -197,7 +197,7 @@
 
 
-// strip annonymous left hand side part of the scope
+// strip anonymous left hand side part of the scope
 QCString stripAnonymousNamespaceScope(const QCString &s)
 {
Index: src/doxygen.cpp
===================================================================
--- src/doxygen.cpp	(Revision 728)
+++ src/doxygen.cpp	(Arbeitskopie)
@@ -680,7 +680,7 @@
           "the second argument in the \\file statement ",
           root->name.data()
                   );
-      if (ambig) // name is ambigious
+      if (ambig) // name is ambiguous
       {
         text+="matches the following input files:\n";
         text+=showFileDefMatches(Doxygen::inputNameDict,root->name);
@@ -736,7 +736,7 @@
                   "the argument of the \\class, \\struct, \\union, or \\include command ",
                   includeFile.data()
                  );
-      if (ambig) // name is ambigious
+      if (ambig) // name is ambiguous
       {
         text+="matches the following input files:\n";
         text+=showFileDefMatches(Doxygen::inputNameDict,root->includeFile);
@@ -2072,7 +2072,7 @@
   {
     if (!root->type.isEmpty() && !root->name.isEmpty())
     {
-      if (name.at(0)=='@') // dummy variable representing annonymous union
+      if (name.at(0)=='@') // dummy variable representing anonymous union
         def=root->type;
       else
         def=root->type+" "+name+root->args;
@@ -2479,8 +2479,8 @@
     {
       MemberDef *md=0;
 
       // if cd is an annonymous scope we insert the member 
       // into a non-annonymous scope as well. This is needed to
       // be able to refer to it using \var or \fn
 
       //int indentDepth=0;
@@ -4411,7 +4411,7 @@
   for (;(rootNav=edi.current());++edi)
   {
     ClassDef *cd;
     // strip any annonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
     Debug::print(Debug::Classes,0,"  Inheritance: Class %s : \n",bName.data());
@@ -4434,7 +4434,7 @@
   for (;(rootNav=edi.current());++edi)
   {
     ClassDef *cd;
     // strip any annonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
     Debug::print(Debug::Classes,0,"  Usage: Class %s : \n",bName.data());
@@ -4460,7 +4460,7 @@
     rootNav->loadEntry(g_storage);
     Entry *root = rootNav->entry();
 
     // strip any annonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
     Debug::print(Debug::Classes,0,"  Relations: Class %s : \n",bName.data());
@@ -4500,7 +4500,7 @@
     QCString bName=stripAnonymousNamespaceScope(root->name);
     bName=stripTemplateSpecifiersFromScope(bName);
     ClassDef *cd=getClass(bName);
     // strip any annonymous scopes first 
     QDict<ClassDef> *templInstances = 0;
     if (cd && (templInstances=cd->getTemplateInstances()))
     {
@@ -2479,8 +2479,8 @@
       MemberDef *md=0;
 
-      // if cd is an annonymous scope we insert the member 
-      // into a non-annonymous scope as well. This is needed to
+      // if cd is an anonymous scope we insert the member 
+      // into a non-anonymous scope as well. This is needed to
       // be able to refer to it using \var or \fn
 
@@ -4411,7 +4411,7 @@
   {
     ClassDef *cd;
-    // strip any annonymous scopes first 
+    // strip any anonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
@@ -4434,7 +4434,7 @@
   {
     ClassDef *cd;
-    // strip any annonymous scopes first 
+    // strip any anonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
@@ -4460,7 +4460,7 @@
     Entry *root = rootNav->entry();
 
-    // strip any annonymous scopes first 
+    // strip any anonymous scopes first 
     QCString bName=stripAnonymousNamespaceScope(rootNav->name());
     bName=stripTemplateSpecifiersFromScope(bName);
@@ -4500,7 +4500,7 @@
     bName=stripTemplateSpecifiersFromScope(bName);
     ClassDef *cd=getClass(bName);
-    // strip any annonymous scopes first 
+    // strip any anonymous scopes first 
     QDict<ClassDef> *templInstances = 0;
     if (cd && (templInstances=cd->getTemplateInstances()))
Index: src/memberdef.cpp
===================================================================
--- src/memberdef.cpp	(Revision 728)
+++ src/memberdef.cpp	(Arbeitskopie)
@@ -355,7 +355,7 @@
     NamespaceDef *nspace;     // the namespace this member is in.
 
     MemberDef  *enumScope;    // the enclosing scope, if this is an enum field
-    MemberDef  *annEnumType;  // the annonymous enum that is the type of this member
+    MemberDef  *annEnumType;  // the anonymous enum that is the type of this member
     MemberList *enumFields;   // enumeration fields
 
     MemberDef  *redefines;    // the members that this member redefines 
@@ -1346,7 +1346,7 @@
   }
 
   // *** write name
-  if (!name().isEmpty() && name().at(0)!='@') // hide annonymous stuff 
+  if (!name().isEmpty() && name().at(0)!='@') // hide anonymous stuff 
   {
     //printf("Member name=`%s gd=%p md->groupDef=%p inGroup=%d isLinkable()=%d\n",name().data(),gd,getGroupDef(),inGroup,isLinkable());
     if (!(name().isEmpty() || name().at(0)=='@') && // name valid
Index: src/lodepng.cpp
===================================================================
--- src/lodepng.cpp	(Revision 728)
+++ src/lodepng.cpp	(Arbeitskopie)
@@ -619,7 +619,7 @@
     /*keep the coins with lowest weight, so that they add up to the amount of symbols - 1*/
     vector_resized(&coins, numpresent - 1, Coin_cleanup);
     
     /*calculate the lenghts of each symbol, as the amount of times a coin of each symbol is used*/
     for(i = 0; i < coins.size; i++)
     {
       Coin* coin = (Coin*)vector_get(&coins, i);
@@ -1266,7 +1266,7 @@
   after the BFINAL and BTYPE, the dynamic block consists out of the following:
   - 5 bits HLIT, 5 bits HDIST, 4 bits HCLEN
   - (HCLEN+4)*3 bits code lengths of code length alphabet
-  - HLIT + 257 code lenghts of lit/length alphabet (encoded using the code length alphabet, + possible repetition codes 16, 17, 18)
+  - HLIT + 257 code lengths of lit/length alphabet (encoded using the code length alphabet, + possible repetition codes 16, 17, 18)
   - HDIST + 1 code lengths of distance alphabet (encoded using the code length alphabet, + possible repetition codes 16, 17, 18)
   - compressed data
   - 256 (end code)
@@ -1282,7 +1282,7 @@
   uivector frequenciesD;
   uivector amounts; /*the amounts in the "normal" order*/
   uivector lldl;
-  uivector lldll; /*lit/len & dist code lenghts*/
+  uivector lldll; /*lit/len & dist code lengths*/
   uivector clcls;
   
   unsigned BFINAL = 1; /*make only one block... the first and final one*/
@@ -1384,7 +1384,7 @@
     if(error) break;
     
     if(!uivector_resize(&clcls, 19)) { error = 9927; break; }
-    for(i = 0; i < 19; i++) clcls.data[i] = HuffmanTree_getLength(&codelengthcodes, CLCL[i]); /*lenghts of code length tree is in the order as specified by deflate*/
+    for(i = 0; i < 19; i++) clcls.data[i] = HuffmanTree_getLength(&codelengthcodes, CLCL[i]); /*lengths of code length tree is in the order as specified by deflate*/
     while(clcls.data[clcls.size - 1] == 0 && clcls.size > 4)
     {
       if(!uivector_resize(&clcls, clcls.size - 1)) { error = 9928; break; } /*remove zeros at the end, but minimum size must be 4*/
@@ -1399,10 +1399,10 @@
     addBitsToStream(&bp, out, HDIST, 5);
     addBitsToStream(&bp, out, HCLEN, 4);
     
     /*write the code lenghts of the code length alphabet*/
     for(i = 0; i < HCLEN + 4; i++) addBitsToStream(&bp, out, clcls.data[i], 3);
   
     /*write the lenghts of the lit/len AND the dist alphabet*/
     for(i = 0; i < lldl.size; i++)
     {
       addHuffmanSymbol(&bp, out, HuffmanTree_getCode(&codelengthcodes, lldl.data[i]), HuffmanTree_getLength(&codelengthcodes, lldl.data[i]));
@@ -619,7 +619,7 @@
     vector_resized(&coins, numpresent - 1, Coin_cleanup);
     
-    /*calculate the lenghts of each symbol, as the amount of times a coin of each symbol is used*/
+    /*calculate the lengths of each symbol, as the amount of times a coin of each symbol is used*/
     for(i = 0; i < coins.size; i++)
     {
@@ -1399,10 +1399,10 @@
     addBitsToStream(&bp, out, HCLEN, 4);
     
-    /*write the code lenghts of the code length alphabet*/
+    /*write the code lengths of the code length alphabet*/
     for(i = 0; i < HCLEN + 4; i++) addBitsToStream(&bp, out, clcls.data[i], 3);
   
@@ -1399,10 +1399,10 @@
     for(i = 0; i < HCLEN + 4; i++) addBitsToStream(&bp, out, clcls.data[i], 3);
   
-    /*write the lenghts of the lit/len AND the dist alphabet*/
+    /*write the lengths of the lit/len AND the dist alphabet*/
     for(i = 0; i < lldl.size; i++)
     {
